#
# spec file for package eth-ff
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define git_ver .0.10e93dd3630c

%define pseudo_opt %{_prefix}/lib/eth-tools/
%define ethsysconfdir %{_sysconfdir}/eth-tools/

Name:           eth-ff
Version:        11.7.0.0
Release:        1.1
Summary:        Intel Ethernet Fabric Suite basic tools and libraries for fabric management
License:        BSD-3-Clause OR GPL-2.0-only
Group:          Productivity/Networking/System
URL:            https://github.com/intel/eth-fast-fabric
Source0:        %{name}-%{version}%{git_ver}.tar.gz
Source1:        eth-ff.rpmlintrc
Patch1:         eth-ff-suse-build-fixes.patch
Patch2:         eth-ff-add-shebang-for-exp-files.patch
BuildRequires:  gcc-c++
BuildRequires:  infiniband-diags-devel
BuildRequires:  libexpat-devel
BuildRequires:  libopenssl-devel
BuildRequires:  librdmacm1
BuildRequires:  ncurses-devel
BuildRequires:  net-snmp-devel
BuildRequires:  rdma-core-devel
BuildRequires:  tcl-devel
BuildRequires:  zlib-devel

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#Currently ONLY builds on x86_64
ExclusiveArch:  x86_64

%description
The %{name} contains basic tools and libraries  to manage an Intel Ethernet fabric.

%package     -n eth-basic-tools
Summary:        Management level tools and scripts
Group:          Productivity/Networking/System
Requires:       rdma

%description -n eth-basic-tools
Contains basic tools for fabric management necessary on all compute nodes.

%package -n eth-fastfabric
Summary:        Management level tools and scripts
Group:          Productivity/Networking/System
Requires:       cron
Requires:       eth-basic-tools

%description -n eth-fastfabric
Contains tools for managing fabric on a management node.

%prep
%autosetup -p0 -n  %{name}-%{version}%{git_ver}

%build
export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -Wno-address-of-packed-member"
cd OpenIb_Host && ./ff_build.sh %{_builddir} $FF_BUILD_ARGS

%install
. OpenIb_Host/ff_filegroups.sh

mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{pseudo_opt}/
mkdir -p %{buildroot}%{pseudo_opt}samples
mkdir -p %{buildroot}%{ethsysconfdir}
mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_mandir}/man8
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/eth-tools

#Binaries and scripts installing (basic tools)
cd $(cat %{_builddir}/RELEASE_PATH)

cd bin
cp -t %{buildroot}%{_sbindir} ${basic_tools_sbin}
cp -t %{buildroot}/%{pseudo_opt}/ ${basic_tools_opt}

cd ../fastfabric
cp -t %{buildroot}%{_sbindir} ${ff_tools_sbin}
cp -t %{buildroot}%{pseudo_opt} ${ff_tools_misc}
cp -t %{buildroot}%{ethsysconfdir} ${basic_configs}

cd ../fastfabric/samples
cp -t %{buildroot}%{pseudo_opt}samples ${ff_iba_samples} ${basic_samples}
cd ..

cd ../fastfabric/tools
chmod 755 *.exp
cp -t %{buildroot}%{pseudo_opt}/ ${ff_tools_exp}
cp -t %{buildroot}%{pseudo_opt}/ ${ff_libs_misc}
cp -t %{buildroot}%{pseudo_opt}/ osid_wrapper
cp -t %{buildroot}%{ethsysconfdir}  allhosts hosts switches
cd ..

cd ../man/man1
cp -t %{buildroot}%{_mandir}/man1 ${basic_mans}
cd ../man8
cp -t %{buildroot}%{_mandir}/man8 ${ff_mans}
cd ..

#Config files
cd ../config
cp -t %{buildroot}/%{ethsysconfdir} ethmon.conf ethmon.si.conf

# Now that we've put everything in the buildroot, copy any default config files to their expected location for user
# to edit. To prevent nuking existing user configs, the files section of this spec file will reference these as noreplace
# config files.
cp %{buildroot}%{pseudo_opt}/ethfastfabric.conf.def %{buildroot}/%{ethsysconfdir}/ethfastfabric.conf

for file in $(ls  %{buildroot}/%{ethsysconfdir}); do
	ln -s %{ethsysconfdir}/$file %{buildroot}/etc/sysconfig/eth-tools/$file
done

#Now we do a bunch of work to build the file listing of what belongs to each RPM

# List for basic
(
	#Basic tools sbin
	for file in ${basic_tools_sbin} ${basic_tools_sbin_sym}; do
		echo "%{_sbindir}/${file}"
	done
	#Basic tools opt
	for file in ${basic_tools_opt}; do
		echo "%{pseudo_opt}/${file}"
	done
	#Basic man pages
	for file in ${basic_mans}; do
		# Extra wildcard to accept .1.gz
		echo "%{_mandir}/man1/${file}*"
	done
	#Basic config pages
	for file in ${basic_configs}; do
		echo "%config(noreplace) %{ethsysconfdir}${file}"
	done
) >  %{_builddir}/basic_file.list

# List for eth-fastfabric
(
	#FF tools opt
	for file in ${ff_tools_opt}; do
		echo "%{pseudo_opt}/${file}"
	done

	#FF exp files opt
	for file in ${ff_tools_exp}; do
		echo "%{pseudo_opt}/${file}"
	done

	#FF misc files opt
	for file in ${ff_tools_misc}; do
		echo "%{pseudo_opt}/${file}"
	done

	#FF libs misc
	for file in ${ff_libs_misc}; do
		echo "%{pseudo_opt}/${file}"
	done

	#FF iba samples
	for file in ${ff_iba_samples} ${basic_samples}; do
		echo "%{pseudo_opt}samples/${file}"
	done

	#FF tools to FM configuration
	for file in ${ff_tools_fm}; do
		echo "%{pseudo_opt}fm_tools/${file}"
	done

	#FF man pages
	for file in ${ff_mans}; do
		# Extra wildcard to accept .8.gz
		echo "%{_mandir}/man8/${file}*"
	done

	#FF tools help doc
	for file in ${help_doc}; do
		echo "%{pseudo_opt}help/${file}"
	done

	#FF tools sbin
	for file in ${ff_tools_sbin}; do
		echo "%{_sbindir}/${file}"
	done

) > %{_builddir}/ff_file.list

%files -n eth-basic-tools -f %{_builddir}/basic_file.list
%defattr(-,root,root,-)
%dir %{pseudo_opt}
%dir %{ethsysconfdir}

%doc README
%license LICENSE

%files -n eth-fastfabric -f %{_builddir}/ff_file.list
%defattr(-,root,root,0755)
%dir %{pseudo_opt}
%dir %{pseudo_opt}samples
%{pseudo_opt}/osid_wrapper

%dir %{_sysconfdir}/sysconfig/eth-tools
%dir %{ethsysconfdir}
%{_sysconfdir}/sysconfig/eth-tools/*

%config(noreplace) %{ethsysconfdir}/ethfastfabric.conf
%config(noreplace) %{ethsysconfdir}/ethmon.conf
%config(noreplace) %{ethsysconfdir}/ethmon.si.conf
%config(noreplace) %{ethsysconfdir}/allhosts
%config(noreplace) %{ethsysconfdir}/hosts
%config(noreplace) %{ethsysconfdir}/switches

%changelog
* Mon Aug 12 2024 Nicolas Morey <nicolas.morey@suse.com>
- Update to v11.7.0.0
  - Improved to support RHEL 9.4/8.10 and SLES 15.6
  - Merged duplicate OS prereq files for major OS versions where possible
  - Added ability to compile IMB-MPI1-GPU with cuda support
  - Cleaned up not needed files
  - Added config on unprivileged access to UserFaultFD
  - Added GPU auto-detection feature
  - Fixed permission and enumeration issues on dsa_setup
  - Improved ethudstress stability to handle unmatched client/server config
  - Improved MpiApps to allow concurrent mpi_apps runs with SLURM
  - Fixed FI_PROVIDER_PATH overrode issue on mpi_apps
  - Updated host verification to check UD QPs, and skip VT-d disabled
    check by default
  - Updated compiler options to enhance security of FastFabric
  - Improved MpiApps README file
  - Improved help for tools ethbw and ethextract*
  - Fixed HPL build for newer version oneAPI
  - Enhanced MpiApps scripts for easier use with SLURM
  - Introduced PSM3_PRINT_STATS_PREFIX to specify PSM3 stats files location
  - Improved MpiApps to support oneCCL benchmark
  - Easy of use improvement on MpiApps
  - Improved parameter files and scripts description
  - Reorganized PSM3 parameter files
  - Improved script printout to include system env
  - Moved MpiApps parameter settings mostly into env vs on MPI cmd line
  - Improved to support RHEL 8.9 and RHEL 9.3
  - Added dsa_setup man page
  - Improved help text and man page for all tools
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Wed Oct  4 2023 Nicolas Morey <nicolas.morey@suse.com>
- Update to v11.5.1.0
  - improved to support SLES 15.5
  - replaced fgrep and egrep with grep -F and grep -E
  - improved ethlinkanalysis/ethfabricanalysis to use first enabled
    plane when it's not specified
  - fixed version comparison issue on install script that happens on
    CUDA version components
  - improved help text and man page for all tools
* Tue Jul 25 2023 Nicolas Morey <nicolas.morey@suse.com>
- Update to v11.5.0.0
  - improved ethreport to support more than 256 ports
  - improved mpi_apps to still build as much as it can when fortran not available
  - improved to support absolute ConfigDir path in mgt_config.xml
  - fixed klocwork issues
  - improved to support SLES 15.4
  - improved ethreport to support bulk query to reduce execution time
  - improved ethreport to get VerdorID in a more stable way
  - improved rping and pfctest execution time
  - fixed timeout issue on pfctest when one node has "large" number of NICs
  - improved ethcabletest and ethfindgood to support fabric plane
  - improved mpiperf and mpiperfdeviation to support fabric plane
  - improved ethreport with below new features:
  - -P/-H: include only persist or hardware data
  - -A/-o otherports: include all or other (inactive) ports
  - -s: include performance data
  - improved node verification to check NIC firmware and driver version
  - improved FastFabric TUI to support multiple fabric planes
  - limited max processes in pfctest to avoid ssh EOF error
  - improved ethudstress to allow specifying port number
  - added tool ethbw to monitor BW per NIC
  - improved ethhostadmin to allow exiting on 1st failed operation
  - enhanced error reporting and handling in rping and pfctest tool
  - added support on Intel GPU (ONEAPI-ZE)
  - fixed ethextract* tool to include performance data
  - code cleanup. removed dead code and tools we do not support.
  - updated MpiApps scripts to pass exe params to commands
  - updated run_osu5 to provide a current list of benchmarks
  - updated get_selected_mpi.sh to work with newer IMPI versions
  - fixed MpiApps build script to allow building HPL with Intel MPI and MKL
  - improved mpiperf and ethcabletest to support multi-rail
  - improved ethreport and related tools to support specifying hostfile via -f
  - changed openblas-devel to be optional prereq
  - fixed klocwork issues in ethbw
  - extended HPL-2.3 building to support different BLAS_TYPE
  - enhanced ethscpall to allow copying data with rsync, specifying net interface to use, and tar compression option
  - changed FastFabric to setup PFC using software DCB (open lldp)
  - renamed FastFabric component "Eth RDMA" to "Eth RoCE"
  - added lldpad as prereq
  - fixed ethlinkanalysis/ethfabricanalysis to honor the ConfigDir defined in mgt_config
  - added rping loopback test and PFC mode check in hostverify
  - improved hostverify to support passive mode intel_pstate
  - fixed ethcabletest to make -n option works properly
  - enhanced ethreport -A to include host ports that have no IP address
  - cleaned up ethreport error messages
  - enhanced ethbw to support duration argument
  - updated man pages for FastFabric tools
  - updated man pages for FastFabric tools
  - Fixed minor bugs on nodeverify.sh, ethshowallports and ethfindgood
  - Improved below tools to support fabric plane
  - ethcabletest.sh
  - ethshowallports.sh
  - ethhostadmin
  - Improved to support RHEL 9.1
  - Fixed RV rebuild issue under SLES 15.4 to support Intel GPU
  - Improved stability on ethcabletest and ethfindgood
  - Added tool dsa_setup to aid creation of DSA devices
  - Changed script shebang to use /bin/bash rather than /bin/sh
  - Improved ethcapture to use journalctl if rsyslog not installed
  - Improved to support Basic-IB package
  - Refactoried package build scripts to better support different OSes
  - Improved dsa_setup to support shared workqueue
  - Cleaned OS detection code
- Refresh eth-ff-add-shebang-for-exp-files.patch
- Drop topology-fix-support-for-disabled-MD5-authentication.patch
  which was fixed upstream.
* Fri Jan 27 2023 Nicolas Morey <nicolas.morey@suse.com>
- Add topology-fix-support-for-disabled-MD5-authentication.patch to fix
  compilation issues with net-snmp with disabled MD5 authentication.
* Thu Sep 15 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v11.3.0.0-130 (jsc#PED-349)
  - added tool ethshmcleanup.sh for obsoleted shm file clean up
  - added support to IMPI 2021.6
  - update MpiApps OSU to v5.9
* Thu Sep 30 2021 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Initial packaging of v11.1.0.0 (jsc#SLE-19364)
